##  Step 1: Build an IT Component Repository
Build a comprehensive IT component repository in SAP LeanIX. For guidelines and best practices on modeling IT components, see [IT Component Modeling Guidelines](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model IT components. This includes best practices and applicable use cases, and common antipatterns.").
Use the SAP LeanIX ServiceNow Integration to bring your software asset data into SAP LeanIX. To learn more, see [ServiceNow Integration](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Fundamentals of the SAP LeanIX integration with ServiceNow \(CMDB\).").
To automate the creation of IT components and provider fact sheets for SaaS services, use the reference catalog. To learn more, see [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.").
